@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Return the borders of states and provinces
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use strictures 2;
 use Carp qw(croak);
@@ -17,9 +17,31 @@ has country => (
     default => sub { 'usa' },
 );
 
+has _canada => (
+    is      => 'ro',
+    isa     => sub { croak "$_[0] is not valid" unless ref $_[0] eq 'HASH' },
+    default => sub {
+      {
+        AB => [qw(BC NT SK)],
+        BC => [qw(AB NT YT)],
+        MB => [qw(NU ON SK)],
+        NB => [qw(NS QC)],
+        NL => [qw(QC)],
+        NS => [qw(NB)],
+        NT => [qw(AB BC NU SK YT)],
+        NU => [qw(MB NT)],
+        ON => [qw(MB QC)],
+        PE => [],
+        QC => [qw(NB NL ON)],
+        SK => [qw(AB MB NT)],
+        YT => [qw(BC NT)],
+      }
+    },
+);
+
 has _usa => (
     is      => 'ro',
-    isa     => sub { croak "$_[0] is not a hash reference" unless ref $_[0] eq 'HASH' },
+    isa     => sub { croak "$_[0] is not valid" unless ref $_[0] eq 'HASH' },
     default => sub {
       {
         AK => [],
@@ -88,7 +110,7 @@ has _usa => (
 
 sub borders {
     my ($self) = @_;
-    my $states = '_' . $self->country;
+    my $states = '_' . lc $self->country;
     return $self->$states();
 }
 
@@ -106,12 +128,12 @@ Geography::States::Borders - Return the borders of states and provinces
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
   use Geography::States::Borders ();
-  my $geo = Geography::States::Borders->new(country => 'usa');
+  my $geo = Geography::States::Borders->new(country => 'USA');
   my $states = $geo->borders('HI'); # empty list
   $states = $geo->borders('OR');    # CA ID NV WA
 
@@ -119,7 +141,7 @@ version 0.0101
 
 C<Geography::States::Borders> returns the borders of states and provinces.
 
-* Currently the only recognized countries are ...the C<usa>.
+* Currently the only recognized countries are the USA and Canada.
 
 =head1 ATTRIBUTES
 
